==> haskell-tamarin-prover-theory-1.2.2-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-tamarin-prover-theory.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tamarin-prover-theory
version: 1.2.2
id: tamarin-prover-theory-1.2.2-6PkdRupSSn5G0WU0Q7OirA
key: tamarin-prover-theory-1.2.2-6PkdRupSSn5G0WU0Q7OirA
license: GPL
copyright: Benedikt Schmidt, Simon Meier, ETH Zurich, 2010-2012
maintainer: Benedikt Schmidt <benedikt.schmidt@inf.ethz.ch>
homepage: http://www.infsec.ethz.ch/research/software/tamarin
synopsis: Term manipulation library for the tamarin prover.
description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).
    .
    This library provides the types to represent security
    protocol, and it implements the constraint solver.
category: Theorem Provers
author: Benedikt Schmidt <benedikt.schmidt@inf.ethz.ch>,
        Simon Meier <simon.meier@inf.ethz.ch>
exposed: True
indefinite: False
exposed-modules:
    Theory Theory.Constraint.Solver
    Theory.Constraint.Solver.Contradictions
    Theory.Constraint.Solver.Goals Theory.Constraint.Solver.ProofMethod
    Theory.Constraint.Solver.Reduction
    Theory.Constraint.Solver.Simplify Theory.Constraint.Solver.Sources
    Theory.Constraint.Solver.Types Theory.Constraint.System
    Theory.Constraint.System.Constraints Theory.Constraint.System.Dot
    Theory.Constraint.System.Guarded Theory.Constraint.System.JSON
    Theory.Model Theory.Model.Atom Theory.Model.Fact
    Theory.Model.Formula Theory.Model.Rule Theory.Model.Signature
    Theory.Proof Theory.Text.Parser Theory.Text.Parser.Token
    Theory.Text.Pretty Theory.Tools.AbstractInterpretation
    Theory.Tools.EquationStore Theory.Tools.InjectiveFactInstances
    Theory.Tools.IntruderRules Theory.Tools.LoopBreakers
    Theory.Tools.RuleVariants Theory.Tools.Wellformedness
abi: 8a53dc52df7d991ca3d8b40752ee5a07
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/tamarin-prover-theory-1.2.2
library-dirs: /usr/lib/ghc-8.2.1/site-local/tamarin-prover-theory-1.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/tamarin-prover-theory-1.2.2
hs-libraries: HStamarin-prover-theory-1.2.2-6PkdRupSSn5G0WU0Q7OirA
depends:
    aeson-1.2.1.0-4B0AgiChYBfAqHGTNuDPfn
    aeson-pretty-0.8.5-5mQUAyrI2r8DbjCzpUnLBP base-4.10.0.0
    binary-0.8.5.1 bytestring-0.10.8.2 containers-0.5.10.2
    deepseq-1.4.3.0 dlist-0.8.0.3-8XCsMwviZunHg7vFDzvN5q
    fclabels-2.0.3.2-C4TftBJxLKb5LMOYkGTlWW
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
    parallel-3.2.1.1-BDA8bigzIyf7HfOpmZ9w2K
    parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh process-1.6.1.0
    safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz transformers-0.5.2.0
    uniplate-1.6.12-7N3IMg4lwN2FPMc94OrKMJ
    tamarin-prover-utils-1.2.2-LVjJJ7aC5vc3QABo3RoZz1
    tamarin-prover-term-1.2.2-E7t9u7QnWmD1bQUA1Lyhy1
abi-depends: aeson-1.2.1.0-4B0AgiChYBfAqHGTNuDPfn=002a869bdbfad797ec5fba636ef9d0d8
             aeson-pretty-0.8.5-5mQUAyrI2r8DbjCzpUnLBP=d0f4e41ab633cc49a53efa4316fcfa87
             base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             binary-0.8.5.1=b72be3099f9dcf7a652ee107dea27d54
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             deepseq-1.4.3.0=ab64de23c9713e035549193002fe9df0
             dlist-0.8.0.3-8XCsMwviZunHg7vFDzvN5q=39b750082c56951484aa28fb24175e9c
             fclabels-2.0.3.2-C4TftBJxLKb5LMOYkGTlWW=5cfa92cab0a3d9d3f1d9409156bd9ebf
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             parallel-3.2.1.1-BDA8bigzIyf7HfOpmZ9w2K=412b6db961d0860f36ea471fc650f639
             parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh=da03630454c215de5f3965e7b0f0e5da
             process-1.6.1.0=c0ee388768c3dd5e8b2d80490997add7
             safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5=6cf1fe7158a61976010b5254caed2ddd
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             uniplate-1.6.12-7N3IMg4lwN2FPMc94OrKMJ=3300bc881e9fb75483828891b71f16f8
             tamarin-prover-utils-1.2.2-LVjJJ7aC5vc3QABo3RoZz1=280a465b2c87b17d4f0b717078e5cdf4
             tamarin-prover-term-1.2.2-E7t9u7QnWmD1bQUA1Lyhy1=412aedeaab51d398f916a26ef52210a9
haddock-interfaces: /usr/share/doc/haskell-tamarin-prover-theory/html/tamarin-prover-theory.haddock
haddock-html: /usr/share/doc/haskell-tamarin-prover-theory/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tamarin-prover-theory-1.2.2-5-i686.pkg.tar.xz: usr/share/haskell/register/haskell-tamarin-prover-theory.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tamarin-prover-theory
version: 1.2.2
id: tamarin-prover-theory-1.2.2-CuPCB5vsb4j5i6JEbwnjr3
key: tamarin-prover-theory-1.2.2-CuPCB5vsb4j5i6JEbwnjr3
license: GPL
copyright: Benedikt Schmidt, Simon Meier, ETH Zurich, 2010-2012
maintainer: Benedikt Schmidt <benedikt.schmidt@inf.ethz.ch>
homepage: http://www.infsec.ethz.ch/research/software/tamarin
synopsis: Term manipulation library for the tamarin prover.
description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).
    .
    This library provides the types to represent security
    protocol, and it implements the constraint solver.
category: Theorem Provers
author: Benedikt Schmidt <benedikt.schmidt@inf.ethz.ch>,
        Simon Meier <simon.meier@inf.ethz.ch>
exposed: True
indefinite: False
exposed-modules:
    Theory Theory.Constraint.Solver
    Theory.Constraint.Solver.Contradictions
    Theory.Constraint.Solver.Goals Theory.Constraint.Solver.ProofMethod
    Theory.Constraint.Solver.Reduction
    Theory.Constraint.Solver.Simplify Theory.Constraint.Solver.Sources
    Theory.Constraint.Solver.Types Theory.Constraint.System
    Theory.Constraint.System.Constraints Theory.Constraint.System.Dot
    Theory.Constraint.System.Guarded Theory.Constraint.System.JSON
    Theory.Model Theory.Model.Atom Theory.Model.Fact
    Theory.Model.Formula Theory.Model.Rule Theory.Model.Signature
    Theory.Proof Theory.Text.Parser Theory.Text.Parser.Token
    Theory.Text.Pretty Theory.Tools.AbstractInterpretation
    Theory.Tools.EquationStore Theory.Tools.InjectiveFactInstances
    Theory.Tools.IntruderRules Theory.Tools.LoopBreakers
    Theory.Tools.RuleVariants Theory.Tools.Wellformedness
abi: 734d6484178e62ee0a76367d74131f5d
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/tamarin-prover-theory-1.2.2
library-dirs: /usr/lib/ghc-8.2.1/site-local/tamarin-prover-theory-1.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/tamarin-prover-theory-1.2.2
hs-libraries: HStamarin-prover-theory-1.2.2-CuPCB5vsb4j5i6JEbwnjr3
depends:
    aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y
    aeson-pretty-0.8.5-LnTyV0zu2iQH6RqpzHnYsx base-4.10.0.0
    binary-0.8.5.1 bytestring-0.10.8.2 containers-0.5.10.2
    deepseq-1.4.3.0 dlist-0.8.0.3-8XCsMwviZunHg7vFDzvN5q
    fclabels-2.0.3.2-C4TftBJxLKb5LMOYkGTlWW
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
    parallel-3.2.1.1-BDA8bigzIyf7HfOpmZ9w2K
    parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh process-1.6.1.0
    safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz transformers-0.5.2.0
    uniplate-1.6.12-7N3IMg4lwN2FPMc94OrKMJ
    tamarin-prover-utils-1.2.2-LVjJJ7aC5vc3QABo3RoZz1
    tamarin-prover-term-1.2.2-E7t9u7QnWmD1bQUA1Lyhy1
abi-depends: aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y=1bd098f0c2fb1217cc4d33a7e7a9941a
             aeson-pretty-0.8.5-LnTyV0zu2iQH6RqpzHnYsx=dc9cfb9ae5ecf7e888b1536da40cda19
             base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             binary-0.8.5.1=b72be3099f9dcf7a652ee107dea27d54
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             deepseq-1.4.3.0=ab64de23c9713e035549193002fe9df0
             dlist-0.8.0.3-8XCsMwviZunHg7vFDzvN5q=39b750082c56951484aa28fb24175e9c
             fclabels-2.0.3.2-C4TftBJxLKb5LMOYkGTlWW=5cfa92cab0a3d9d3f1d9409156bd9ebf
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             parallel-3.2.1.1-BDA8bigzIyf7HfOpmZ9w2K=412b6db961d0860f36ea471fc650f639
             parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh=da03630454c215de5f3965e7b0f0e5da
             process-1.6.1.0=c0ee388768c3dd5e8b2d80490997add7
             safe-0.3.15-AsY8t7BqxG7J4M7E7fbih5=6cf1fe7158a61976010b5254caed2ddd
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             uniplate-1.6.12-7N3IMg4lwN2FPMc94OrKMJ=3300bc881e9fb75483828891b71f16f8
             tamarin-prover-utils-1.2.2-LVjJJ7aC5vc3QABo3RoZz1=280a465b2c87b17d4f0b717078e5cdf4
             tamarin-prover-term-1.2.2-E7t9u7QnWmD1bQUA1Lyhy1=412aedeaab51d398f916a26ef52210a9
haddock-interfaces: /usr/share/doc/haskell-tamarin-prover-theory/html/tamarin-prover-theory.haddock
haddock-html: /usr/share/doc/haskell-tamarin-prover-theory/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
